@@ -32,7 +32,8 @@ taxa_tbl <- function(
   tbl_name <- paste0("v", version, "_", schema, "_", provider)
 
   if (is.null(db)){
-    return(quick_db(provider, schema, version))
+    warning("NULL db not supported")
+    db = td_connect()
   }
   if (!has_table(tbl_name, db)){
     td_create(provider = provider, schema = schema, version = version, db = db)
@@ -47,14 +48,4 @@ has_table <- function(table = NULL, db = td_connect()){
   else FALSE
 }
 
-#' @importFrom readr read_tsv
-quick_db <-
-  function(provider, schema, version){
-    tmp <- tl_import(provider, schema, version)
 
-    suppressWarnings(
-      readr::read_tsv(file(tmp),
-      col_types = readr::cols(.default = readr::col_character()),
-      lazy = FALSE)
-    )
-  }
